Stan Math Library: stan::math::seq_view< T, std::vector< T > > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | List of all members
stan::math::seq_view< T, std::vector< T > > Class Template Reference

`#include <seq_view.hpp>`

## Public Member Functions
| seq_view (typename pass_type< std::vector< T > >::type x)
pass_type< T >::type | operator[] (int n) const
int | size () const

## Detailed Description

### template<typename T>
class stan::math::seq_view< T, std::vector< T > >

Definition at line 141 of file seq_view.hpp.

## Constructor & Destructor Documentation

template<typename T >

stan::math::seq_view< T, std::vector< T > >::seq_view | ( | typename pass_type< std::vector< T > >::type | x | ) |
| inlineexplicit

Definition at line 145 of file seq_view.hpp.

## Member Function Documentation

template<typename T >

pass_type<T>::type stan::math::seq_view< T, std::vector< T > >::operator[] | ( | int | n | ) | const
| inline

Definition at line 149 of file seq_view.hpp.

template<typename T >

int stan::math::seq_view< T, std::vector< T > >::size | ( |  | ) | const
| inline

Definition at line 152 of file seq_view.hpp.

The documentation for this class was generated from the following file:

- stan/math/prim/mat/meta/seq_view.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.